@@ -6,6 +6,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,24 +15,28 @@
  *
  * This file is part of GNU SHOGI.
  *
- * GNU Shogi is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 1, or (at your option)
- * any later version.
+ * GNU Shogi is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
- * GNU Shogi is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with GNU Shogi; see the file COPYING.  If not, write to
- * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ * ----------------------------------------------------------------------
  */
 
+/* request *snprintf prototypes*/
+#define _POSIX_C_SOURCE 200112L
 
 #include <ctype.h>
 #include <signal.h>
+#include <stdio.h>
 
 #include <sys/param.h>
 #include <sys/types.h>
@@ -41,14 +46,28 @@
 #include "gnushogi.h"
 #include "cursesdsp.h"
 
+#if HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#if HAVE_SYS_FILIO_H
+/* Definition of FIONREAD */
+#include <sys/filio.h>
+#endif
+
+#if HAVE_ERRNO_H
+/* Definition of errno(). */
+#include <errno.h>
+#endif
+
 #define FLUSH_SCANW fflush(stdout), scanw
 
 int mycnt1, mycnt2;
 
 #define TAB (58)
 
-#define VIR_C(s)  ((flag.reverse) ? (8 - column(s)) : column(s))
-#define VIR_R(s)  ((flag.reverse) ? (8 - row(s)) : row(s))
+#define VIR_C(s)  ((flag.reverse) ? (NO_COLS - 1 - column(s)) : column(s))
+#define VIR_R(s)  ((flag.reverse) ? (NO_ROWS - 1 - row(s)) : row(s))
 
 unsigned short MV[MAXDEPTH];
 int MSCORE;
@@ -58,13 +77,14 @@ char *DRAW;
 /* FIXME: change this name, puh-leeze! */
 
 static void UpdateCatched(void);
-
+static void DrawPiece(short sq);
+static void ShowScore(short score);
 
 /****************************************
  * Trivial output functions.
  ****************************************/
 
-void
+static void
 ClearEoln(void)
 {
     clrtoeol();
@@ -80,7 +100,14 @@ Curses_ClearScreen(void)
 }
 
 
-void
+static void
+gotoXY(short x, short y)
+{
+    move(y - 1, x - 1);
+}
+
+
+static void
 ClearMessage(void)
 {
     gotoXY(TAB, 6);
@@ -88,14 +115,6 @@ ClearMessage(void)
 }
 
 
-
-void
-gotoXY(short x, short y)
-{
-    move(y - 1, x - 1);
-}
-
-
 void
 Curses_ShowCurrentMove(short pnt, short f, short t)
 {
@@ -109,7 +128,7 @@ void
 Curses_ShowDepth(char ch)
 {
     gotoXY(TAB, 4);
-    printw(CP[53], Sdepth, ch);   /* Depth = %d%c */
+    printw("Depth= %d%c ", Sdepth, ch);
     ClearEoln();
 }
 
@@ -129,7 +148,7 @@ void
 ShowHeader(void)
 {
     gotoXY(TAB, 2);
-    printw(CP[69], version, patchlevel);
+    printw("GNU Shogi %s", PACKAGE_VERSION);
 }
 
 
@@ -149,10 +168,43 @@ Curses_ShowMessage(char *s)
 
 
 void
-ShowNodeCnt(long NodeCnt)
+Curses_AlwaysShowMessage(const char *format, va_list ap)
+{
+    static char buffer[60];
+    vsnprintf(buffer, sizeof(buffer), format, ap);
+    Curses_ShowMessage(buffer);
+}
+
+
+void
+Curses_Printf(const char *format, va_list ap)
+{
+    static char buffer[60];
+    vsnprintf(buffer, sizeof(buffer), format, ap);
+    printw("%s", buffer);
+}
+
+
+void
+Curses_doRequestInputString(const char* fmt, char* buffer)
+{
+    FLUSH_SCANW(fmt, buffer);
+}
+
+
+int
+Curses_GetString(char* sx)
+{
+    fflush(stdout);
+    return (getstr(sx) == ERR);
+}
+
+
+void
+Curses_ShowNodeCnt(long NodeCnt)
 {
     gotoXY(TAB, 22);
-    /* printw(CP[90], NodeCnt, (et > 100) ? NodeCnt / (et / 100) : 0); */
+    /* printw("Nodes = %8ld, Nodes/Sec = %5ld", NodeCnt, (et > 100) ? NodeCnt / (et / 100) : 0); */
     printw("n = %ld n/s = %ld", 
            NodeCnt, (et > 100) ? NodeCnt / (et / 100) : 0);
     ClearEoln();
@@ -164,7 +216,7 @@ Curses_ShowPatternCount(short side, short n)
 {
     if (flag.post)
     {
-        gotoXY(TAB + 10 + 3 * side, 20);
+        gotoXY(TAB + 10 + 3 * side, 20);	  /* CHECKME */
 
         if (n >= 0)
             printw("%3d", n);
@@ -174,21 +226,22 @@ Curses_ShowPatternCount(short side, short n)
 }
 
 
-void
+static void
 ShowPlayers(void)
 {
-    gotoXY(5, ((flag.reverse) ? 23 : 2));
-    printw("%s", (computer == white) ? CP[218] : CP[74]);
-    gotoXY(5, ((flag.reverse) ? 2 : 23));
-    printw("%s", (computer == black) ? CP[218] : CP[74]);
+    gotoXY(5, ((flag.reverse) ? (5 + 2*NO_ROWS) : 2));
+    printw("%s", (computer == white) ? "Computer" : "Human   ");
+    gotoXY(5, ((flag.reverse) ? 2 : (5 + 2*NO_ROWS)));
+    printw("%s", (computer == black) ? "Computer" : "Human   ");
 }
 
 
 void
-ShowPrompt(void)
+Curses_ShowPrompt(void)
 {
+    Curses_ShowSidetoMove();
     gotoXY(TAB, 17);
-    printw(CP[121]);     /* Your move is? */
+    printw("Your move is? ");
     ClearEoln();
 }
 
@@ -200,8 +253,6 @@ Curses_ShowResponseTime(void)
     {
         short TCC = TCcount;
         gotoXY(TAB, 21);
-        /* printw("RT = %ld TCC = %d TCL = %ld EX = %ld ET = %ld TO = %d",
-           ResponseTime, TCC, TCleft, ExtraTime, et, flag.timeout); */
         printw("%ld, %d, %ld, %ld, %ld, %d",
                ResponseTime, TCC, TCleft, ExtraTime, et, flag.timeout);
         ClearEoln();
@@ -244,11 +295,11 @@ Curses_ShowResults(short score, unsigned short *bstline, char ch)
 }
 
 
-void
+static void
 ShowScore(short score)
 {
     gotoXY(TAB, 5);
-    printw(CP[104], score);
+    printw("Score= %d", score);
     ClearEoln();
 }
 
@@ -271,12 +322,10 @@ Curses_ShowStage(void)
     ClearEoln();
 }
 
-
 /****************************************
  * End of trivial output routines.
  ****************************************/
 
-
 void
 Curses_Initialize(void)
 {
@@ -303,7 +352,6 @@ Curses_ExitShogi(void)
 }
 
 
-
 void
 Curses_Die(int sig)
 {
@@ -312,10 +360,10 @@ Curses_Die(int sig)
     signal(SIGINT, SIG_IGN);
     signal(SIGQUIT, SIG_IGN);
 
-    Curses_ShowMessage(CP[31]);     /* Abort? */
+    Curses_ShowMessage("Abort? ");
     FLUSH_SCANW("%s", s);
 
-    if (strcmp(s, CP[210]) == 0) /* yes */
+    if (strcmp(s, "yes") == 0)
         Curses_ExitShogi();
 
     signal(SIGINT, Curses_Die);
@@ -323,7 +371,6 @@ Curses_Die(int sig)
 }
 
 
-
 void
 Curses_TerminateSearch(int sig)
 {
@@ -340,81 +387,48 @@ Curses_TerminateSearch(int sig)
 }
 
 
-
 void
 Curses_help(void)
 {
     Curses_ClearScreen();
-    /* printw("GNU Shogi ??p? command summary\n"); */
-    printw(CP[40], version, patchlevel);
+    printw("GNU Shogi %s command summary\n", PACKAGE_VERSION);
     printw("-------------------------------"
            "---------------------------------\n");
-    /* printw("7g7f      move from 7g to 7f      quit      
-     * Exit Shogi\n"); */
-    printw(CP[158]);
-    /* printw("S6h       move silver to 6h       beep      
-     * turn %s\n", (flag.beep) ? "off" : "on"); */
-    printw(CP[86], (flag.beep) ? CP[92] : CP[93]);
-    /* printw("2d2c+     move to 2c and promote\n"); */
-    printw(CP[128], (flag.material) ? CP[92] : CP[93]);
-    /* printw("P*5e      drop a pawn to 5e       easy      
-     * turn %s\n", (flag.easy) ? "off" : "on"); */
-    printw(CP[173], (flag.easy) ? CP[92] : CP[93]);
-    /* printw("                                  hash      
-     * turn %s\n", (flag.hash) ? "off" : "on"); */
-    printw(CP[174], (flag.hash) ? CP[92] : CP[93]);
-    /* printw("bd        redraw board            reverse   
-     * board display\n"); */
-    printw(CP[130]);
-    /* printw("list      game to shogi.lst       book      
-     * turn %s used %d of %d\n", (Book) ? "off" : "on", book
-      count, booksize); */
-    printw(CP[170], (Book) ? CP[92] : CP[93], bookcount, BOOKSIZE);
-    /* printw("undo      undo last ply           remove    
-     * take back a move\n"); */
-    printw(CP[200]);
-    /* printw("edit      edit board              force     
-     * enter game moves\n"); */
-    printw(CP[153]);
-    /* printw("switch    sides with computer     both      
-     * computer match\n"); */
-    printw(CP[194]);
-    /* printw("black     computer plays black    white     
-     * computer plays white\n"); */
-    printw(CP[202]);
-    /* printw("depth     set search depth        clock     
-     * set time control\n"); */
-    printw(CP[149]);
-    /* printw("hint      suggest a move         post      
-     * turn %s principle variation\n", (flag.post) ? "off" :
-     * "on"); */
-    printw(CP[177], (flag.post) ? CP[92] : CP[93]);
-    /* printw("save      game to file            get       
-     * game from file\n"); */
-    printw(CP[188]);
-    /* printw("random    randomize play          new       
-     * start new game\n"); */
-    printw(CP[181]);
+    printw("7g7f      move from 7g to 7f      quit      Exit Shogi\n");
+    printw("S6h       move silver to 6h       beep      turn %s\n", (flag.beep) ? "OFF" : "ON");
+    printw("2d2c+     move to 2c and promote  material  turn %s\n", (flag.material) ? "OFF" : "ON");
+    printw("P*5e      drop pawn to 5e         easy      turn %s\n", (flag.easy) ? "OFF" : "ON");
+    printw("tsume     toggle tsume mode       hash      turn %s\n", (flag.hash) ? "OFF" : "ON");
+    printw("bd        redraw board            reverse   board display\n");
+    printw("list      game to shogi.lst       book      turn %s used %d of %d\n", (Book) ? "OFF" : "ON", bookcount, BOOKSIZE);
+    printw("undo      undo last ply           remove    take back a move\n");
+    printw("edit      edit board              force     toggle manual move mode\n");
+    printw("switch    sides with computer     both      computer match\n");
+    printw("black     computer plays black    white     computer plays white\n");
+    printw("depth     set search depth        clock     set time control\n");
+    printw("post      principle variation     hint      suggest a move\n", (flag.post) ? "OFF" : "ON");
+    printw("save      game to file            get       game from file\n");
+    printw("random    randomize play          new       start new game\n");
     gotoXY(10, 20);
-    printw(CP[47], ColorStr[computer]);
+    printw("Computer: %s", ColorStr[computer]);
     gotoXY(10, 21);
-    printw(CP[97], ColorStr[opponent]);
+    printw("Opponent: %s", ColorStr[opponent]);
     gotoXY(10, 22);
-    printw(CP[79], MaxResponseTime/100);
+    printw("Level: %ld", MaxResponseTime/100);
     gotoXY(10, 23);
-    printw(CP[59], (flag.easy) ? CP[93] : CP[92]);
+    printw("Easy mode: %s", (flag.easy) ? "ON" : "OFF");
     gotoXY(25, 23);
-    printw(CP[231], (flag.tsume) ? CP[93] : CP[92]);
+    printw("Tsume: %s", (flag.tsume) ? "ON" : "OFF");
     gotoXY(40, 20);
-    printw(CP[52], MaxSearchDepth);
+    printw("Depth: %d", MaxSearchDepth);
     gotoXY(40, 21);
-    printw(CP[100], (dither) ? CP[93] : CP[92]);
+    printw("Random: %s", (dither) ? "ON" : "OFF");
     gotoXY(40, 22);
-    printw(CP[112], (flag.hash) ? CP[93] : CP[92]);
+    printw("Transposition table: %s", (flag.hash) ? "ON" : "OFF");
     gotoXY(40, 23);
-    printw(CP[73]);
+    printw("Hit <RET> to return: ");
     gotoXY(10, 24);
-    printw(CP[110], (TCflag) ? CP[93] : CP[92],
+    printw("Time Control %s %d moves %d sec %d add %d depth\n", (TCflag) ? "ON" : "OFF",
            TimeControl.moves[black], 
            TimeControl.clock[black] / 100, 
            OperatorTime, MaxSearchDepth);
@@ -453,24 +467,24 @@ Curses_EditBoard(void)
     Curses_ClearScreen();
     Curses_UpdateDisplay(0, 0, 1, 0);
     gotoXY(TAB, 3);
-    printw(CP[29]);
+    printw(".   Exit to main\n");
     gotoXY(TAB, 4);
-    printw(CP[28]);
+    printw("#   Clear board\n");
     gotoXY(TAB, 5);
-    printw(CP[136]);
+    printw("c   Change sides\n");
     gotoXY(TAB, 7);
-    printw(CP[64]);
+    printw("Enter piece & location: ");
     a = black;
 
     do
     {
         gotoXY(TAB, 6);
-        printw(CP[60], ColorStr[a]); /* Editing %s */
+        printw("Editing: %s", ColorStr[a]);
         gotoXY(TAB + 24, 7);
         ClearEoln();
         FLUSH_SCANW("%s", s);
 
-        if (s[0] == CP[28][0])    /* # */
+        if (s[0] == '#')
         {
             for (sq = 0; sq < NO_SQUARES; sq++)
             {
@@ -483,7 +497,7 @@ Curses_EditBoard(void)
             UpdateCatched();
         }
 
-        if (s[0] == CP[136][0])   /* c */
+        if (s[0] == 'c')
             a = otherside[a];
 
         if (s[1] == '*')
@@ -500,8 +514,8 @@ Curses_EditBoard(void)
         }
         else
         {
-            c = '9' - s[1];
-            r = 'i' - s[2];
+            c = COL_NAME(s[1]);
+            r = ROW_NAME(s[2]);
         }
 
         if ((c >= 0) && (c < NO_COLS) && (r >= 0) && (r < NO_ROWS))
@@ -524,7 +538,7 @@ Curses_EditBoard(void)
             DrawPiece(sq);
         }
     }
-    while (s[0] != CP[29][0]);  /* . */
+    while (s[0] != '.');
 
     for (sq = 0; sq < NO_SQUARES; sq++)
         Mvboard[sq] = ((board[sq] != Stboard[sq]) ? 10 : 0);
@@ -539,7 +553,6 @@ Curses_EditBoard(void)
 }
 
 
-
 static void 
 UpdateCatched()
 {
@@ -591,7 +604,6 @@ UpdateCatched()
 }
 
 
-
 void
 Curses_SearchStartStuff(short side)
 {
@@ -600,7 +612,7 @@ Curses_SearchStartStuff(short side)
     signal(SIGINT, Curses_TerminateSearch);
     signal(SIGQUIT, Curses_TerminateSearch);
 
-    for (i = 4; i < 14; i++)
+    for (i = 4; i < 14; i++)			  /* CHECKME */
     {
         gotoXY(TAB, i);
         ClearEoln();
@@ -608,7 +620,6 @@ Curses_SearchStartStuff(short side)
 }
 
 
-
 void
 Curses_OutputMove(void)
 {
@@ -618,11 +629,11 @@ Curses_OutputMove(void)
 
     if (flag.illegal) 
     {
-        printw(CP[225]);
+        printw("Illegal position.");
         return;
     }
 
-    printw(CP[84], mvstr[0]);    /* My move is %s */
+    printw("My move is: %5s", mvstr[0]);
 
     if (flag.beep)
         putchar(7);
@@ -632,16 +643,16 @@ Curses_OutputMove(void)
     gotoXY(TAB, 18);
 
     if (root->flags & draw)
-        printw(CP[58]);
+        printw("Drawn game!");
     else if (root->score == -(SCORE_LIMIT + 999))
-        printw(CP[95]);
+        printw("Opponent mates!");
     else if (root->score == SCORE_LIMIT + 998)
-        printw(CP[44]);
+        printw("Computer mates!");
 #ifdef VERYBUGGY
     else if (root->score < -SCORE_LIMIT)
-        printw(CP[96], SCORE_LIMIT + 999 + root->score - 1);
+        printw("Opp: mate in %d!", SCORE_LIMIT + 999 + root->score - 1);
     else if (root->score > SCORE_LIMIT)
-        printw(CP[45], SCORE_LIMIT + 998 - root->score - 1);
+        printw("Comp: mate in %d!", SCORE_LIMIT + 998 - root->score - 1);
 #endif /* VERYBUGGY */
 
     ClearEoln();
@@ -666,7 +677,7 @@ Curses_OutputMove(void)
 
         ShowNodeCnt(NodeCnt);
         gotoXY(TAB, 23);
-        printw(CP[81], t); /* Max Tree= */
+        printw("Max Tree = %5d", t);
         ClearEoln();
     }
 
@@ -674,9 +685,8 @@ Curses_OutputMove(void)
 }
 
 
-
 void
-UpdateClocks(void)
+Curses_UpdateClocks(void)
 {
     short m, s;
     long dt;
@@ -713,8 +723,7 @@ UpdateClocks(void)
 }
 
 
-
-void
+static void
 DrawPiece(short sq)
 {
     char y;
@@ -747,23 +756,20 @@ DrawPiece(short sq)
         y = pxx[(int)piece];
     }
 
-    gotoXY(8 + 5 * VIR_C(sq), 4 + 2 * (8 - VIR_R(sq)));
+    gotoXY(8 + 5 * VIR_C(sq), 4 + 2 * ((NO_ROWS - 1) - VIR_R(sq)));
     printw("%c%c%c%c", l, p, y, r);
 }
 
 
-
-
 /*
  * Curses_ShowPostnValue(): must have called ExaminePosition() first
  */
-
 void
 Curses_ShowPostnValue(short sq)
 {
     short score;
 
-    gotoXY(4 + 5 * VIR_C(sq), 5 + 2 * (7 - VIR_R(sq)));
+    gotoXY(4 + 5 * VIR_C(sq), 5 + 2 * (7 - VIR_R(sq)));	/* CHECKME */
     score = ScorePosition(color[sq]);
 
     if (color[sq] != neutral)
@@ -783,7 +789,6 @@ Curses_ShowPostnValue(short sq)
 }
 
 
-
 void
 Curses_ShowPostnValues(void)
 {
@@ -796,7 +801,7 @@ Curses_ShowPostnValues(void)
 
     score = ScorePosition(opponent);
     gotoXY(TAB, 5);
-    printw(CP[103], score, 
+    printw("S%d m%d ps%d gt%c m%d ps%d gt%c", score,
            mtl[computer], pscore[computer], GameType[computer],
            mtl[opponent], pscore[opponent], GameType[opponent]);
 
@@ -804,11 +809,11 @@ Curses_ShowPostnValues(void)
 }
 
 
-
 void
 Curses_UpdateDisplay(short f, short t, short redraw, short isspec)
 {
     short i, sq, z;
+    int j;
 
     if (redraw)
     {
@@ -818,37 +823,51 @@ Curses_UpdateDisplay(short f, short t, short redraw, short isspec)
         i = 2;
         gotoXY(3, ++i);
 
-        printw("    +----+----+----+----+----+----+----+----+----+");
+        printw("    +");
+	for (j=0; j<NO_COLS; j++)
+	    printw("----+");
 
-        while (i < 20)
+        while (i <= 1 + 2*NO_ROWS)
         {
             gotoXY(1, ++i);
 
             if (flag.reverse)
                 z = (i / 2) - 1;
             else
-                z = 11 - ((i + 1) / 2);
+                z = NO_ROWS + 2 - ((i + 1) / 2);
 
-            printw("    %c |    |    |    |    |    |"
-                   "    |    |    |    |", 'a' + 9 - z);
+            printw("    %c |", ROW_NAME(z+1));
+	    for (j=0; j<NO_COLS; j++)
+		printw("    |");
 
             gotoXY(3, ++i);
 
-            if (i < 20)
+            if (i < 2 + 2*NO_ROWS)
             {
-                printw("    +----+----+----+----+----+----+----+----+----+");
+		printw("    +");
+		for (j=0; j<NO_COLS; j++)
+		    printw("----+");
             }
         }
 
-        printw("    +----+----+----+----+----+----+----+----+----+");
+	printw("    +");
+	for (j=0; j<NO_COLS; j++)
+	    printw("----+");
 
-        gotoXY(3, 22);
+        gotoXY(3, 4 + 2*NO_ROWS);
         printw("    ");
 
+#ifndef MINISHOGI
         if (flag.reverse)
-            printw(CP[16]);
+            printw("  1    2    3    4    5    6    7    8    9");
         else
-            printw(CP[15]);
+            printw("  9    8    7    6    5    4    3    2    1");
+#else
+        if (flag.reverse)
+            printw("  1    2    3    4    5");
+        else
+            printw("  1    2    3    4    5");
+#endif
 
         for (sq = 0; sq < NO_SQUARES; sq++)
             DrawPiece(sq);
@@ -908,31 +927,26 @@ Curses_UpdateDisplay(short f, short t, short redraw, short isspec)
 }
 
 
-extern char *InPtr;
-
-
 void
 Curses_ChangeAlphaWindow(void)
 {
-    Curses_ShowMessage(CP[114]);
+    Curses_ShowMessage("WAwindow = ");
     FLUSH_SCANW("%hd", &WAwindow);
-    Curses_ShowMessage(CP[34]);
+    Curses_ShowMessage("BAwindow = ");
     FLUSH_SCANW("%hd", &BAwindow);
 }
 
 
-
 void
 Curses_ChangeBetaWindow(void)
 {
-    Curses_ShowMessage(CP[115]);
+    Curses_ShowMessage("WBwindow = ");
     FLUSH_SCANW("%hd", &WBwindow);
-    Curses_ShowMessage(CP[35]);
+    Curses_ShowMessage("BBwindow = ");
     FLUSH_SCANW("%hd", &BBwindow);
 }
 
 
-
 void
 Curses_GiveHint(void)
 {
@@ -941,22 +955,21 @@ Curses_GiveHint(void)
     if (hint)
     {
         algbr((short) (hint >> 8), (short) (hint & 0xFF), false);
-        strcpy(s, CP[198]);  /* try */
+        strcpy(s, "try ");
         strcat(s, mvstr[0]);
         Curses_ShowMessage(s);
     }
     else
     {
-        Curses_ShowMessage(CP[223]);
+        Curses_ShowMessage("I have no idea.\n");
     }
 }
 
 
-
 void
 Curses_ChangeSearchDepth(void)
 {
-    Curses_ShowMessage(CP[150]);
+    Curses_ShowMessage("depth = ");
     FLUSH_SCANW("%hd", &MaxSearchDepth);
     TCflag = !(MaxSearchDepth > 0);
 }
@@ -965,9 +978,9 @@ Curses_ChangeSearchDepth(void)
 void
 Curses_ChangeHashDepth(void)
 {
-    Curses_ShowMessage(CP[163]);
+    Curses_ShowMessage("hashdepth = ");
     FLUSH_SCANW("%hd", &HashDepth);
-    Curses_ShowMessage(CP[82]);
+    Curses_ShowMessage("MoveLimit = ");
     FLUSH_SCANW("%hd", &HashMoveLimit);
 }
 
@@ -975,21 +988,19 @@ Curses_ChangeHashDepth(void)
 void
 Curses_SetContempt(void)
 {
-    Curses_ShowMessage(CP[142]);
+    Curses_ShowMessage("contempt = ");
     FLUSH_SCANW("%hd", &contempt);
 }
 
 
-
 void
 Curses_ChangeXwindow(void)
 {
-    Curses_ShowMessage(CP[208]);
+    Curses_ShowMessage("xwndw= ");
     FLUSH_SCANW("%hd", &xwndw);
 }
 
 
-
 void
 Curses_SelectLevel(char *sx)
 {
@@ -997,27 +1008,27 @@ Curses_SelectLevel(char *sx)
 
     Curses_ClearScreen();
     gotoXY(32, 2);
-    printw(CP[41], version, patchlevel);
+    printw("GNU Shogi %s", PACKAGE_VERSION);
     gotoXY(20, 4);
-    printw(CP[18]);
+    printw(" 1.   40 moves in   5 minutes");
     gotoXY(20, 5);
-    printw(CP[19]);
+    printw(" 2.   40 moves in  15 minutes");
     gotoXY(20, 6);
-    printw(CP[20]);
+    printw(" 3.   40 moves in  30 minutes");
     gotoXY(20, 7);
-    printw(CP[21]);
+    printw(" 4.  all moves in  15 minutes");
     gotoXY(20, 8);
-    printw(CP[22]);
+    printw(" 5.  all moves in  30 minutes");
     gotoXY(20, 9);
-    printw(CP[23]);
+    printw(" 6.  all moves in  15 minutes, 30 seconds fischer clock");
     gotoXY(20, 10);
-    printw(CP[24]);
+    printw(" 7.  all moves in  30 minutes, 30 seconds fischer clock");
     gotoXY(20, 11);
-    printw(CP[25]);
+    printw(" 8.    1 move  in   1 minute");
     gotoXY(20, 12);
-    printw(CP[26]);
+    printw(" 9.    1 move  in  15 minutes");
     gotoXY(20, 13);
-    printw(CP[27]);
+    printw("10.    1 move  in  30 minutes");
 
     OperatorTime = 0;
     TCmoves = 40;
@@ -1025,7 +1036,7 @@ Curses_SelectLevel(char *sx)
     TCseconds = 0;
 
     gotoXY(20, 17);
-    printw(CP[62]);
+    printw("Enter Level: ");
     refresh();
     FLUSH_SCANW("%d", &item);
 
@@ -1100,7 +1111,6 @@ Curses_SelectLevel(char *sx)
 }
 
 
-
 void
 Curses_DoDebug(void)
 {
@@ -1108,14 +1118,14 @@ Curses_DoDebug(void)
     char s[40];
 
     ExaminePosition(opponent);
-    Curses_ShowMessage(CP[65]);
+    Curses_ShowMessage("Enter piece: ");
     FLUSH_SCANW("%s", s);
     c = neutral;
 
-    if ((s[0] == CP[9][0]) || (s[0] == CP[9][1])) /* b B */
+    if ((s[0] == 'b') || (s[0] == 'B'))
         c = black;
 
-    if ((s[0] == CP[9][2]) || (s[0] == CP[9][3])) /* w W */
+    if ((s[0] == 'w') || (s[0] == 'W'))
         c = white;
 
     for (p = king; p > no_piece; p--)
@@ -1140,7 +1150,7 @@ Curses_DoDebug(void)
 
     score = ScorePosition(opponent);
     gotoXY(TAB, 5);
-    printw(CP[103], score, 
+    printw("S%d m%d ps%d gt%c m%d ps%d gt%c", score,
            mtl[computer], pscore[computer], GameType[computer],
            mtl[opponent], pscore[opponent], GameType[opponent]);
 
@@ -1148,7 +1158,6 @@ Curses_DoDebug(void)
 }
 
 
-
 void
 Curses_DoTable(short table[NO_SQUARES])
 {
@@ -1163,4 +1172,34 @@ Curses_DoTable(short table[NO_SQUARES])
 } 
 
 
+void
+Curses_PollForInput(void)
+{
+    int  i;
+    int  nchar;
 
+    if ((i = ioctl((int) 0, FIONREAD, &nchar)))
+    {
+        perror("FIONREAD");
+        fprintf(stderr,
+                "You probably have a non-ANSI <ioctl.h>; "
+                "see README. %d %d %x\n",
+                i, errno, FIONREAD);
+        exit(1);
+    }
+
+    if (nchar)
+    {
+        if (!flag.timeout)
+            flag.back = true;
+
+        flag.bothsides = false;
+    }
+}
+
+
+void
+Curses_SetupBoard(void)
+{
+    Curses_ShowMessage("'setup' command is not supported in Cursesmode");
+}
