@@ -4,6 +4,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,8 +15,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -23,13 +24,12 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
 
-#include "version.h"
 #include "gnushogi.h"
 
 #include <signal.h>
@@ -95,12 +95,13 @@ main (int argc, char **argv)
             break;
 #endif
 
+#ifdef HAVE_LIBCURSES
         case 'C':
             /* Curses interface. */
             display_type = DISPLAY_CURSES;
 
             break;
-
+#endif
 
         case 'h':
             /* Need the "+" syntax here... */
@@ -211,7 +212,7 @@ main (int argc, char **argv)
                 long j;
                 struct fileentry n;
 
-                printf(CP[66]);
+                fputs("Filling transposition file, wait!\n", stdout);
                 n.f = n.t = 0;
                 n.flags = 0;
                 n.depth = 0;
@@ -224,7 +225,7 @@ main (int argc, char **argv)
             }
             else
             {
-                printf(CP[50], HASHFILE);
+                printf("Create failed for %s\n", HASHFILE);
             }
 
             return 0;
@@ -245,7 +246,7 @@ main (int argc, char **argv)
                 int nr[MAXDEPTH];
                 struct fileentry n;
 
-                printf(CP[49]);
+                fputs("Counting transposition file entries, wait!\n", stdout);
 
                 for (i = 0; i < MAXDEPTH; i++)
                     nr[i] = 0;
@@ -271,7 +272,7 @@ main (int argc, char **argv)
                     }
                 }
 
-                printf(CP[109], nr[0], i);
+                printf("The file contains %d entries out of max %d\n", nr[0], i);
 
                 for (j = 1; j < MAXDEPTH; j++)
                     printf("%d ", nr[j]);
@@ -286,7 +287,7 @@ main (int argc, char **argv)
 #endif /* ttblsz */
 
         case 'v':
-            fprintf(stderr, CP[102], version, patchlevel);
+            fprintf(stderr, "gnushogi version %s\n", PACKAGE_VERSION);
             exit(1);
 
 
@@ -308,7 +309,7 @@ main (int argc, char **argv)
 
 
         default:
-            fprintf(stderr, CP[113]);
+            fputs("Usage: gnushogi [-a] [-t] [-c size] [-s savefile][-l listfile] [-x xwndw]\n", stderr);
             exit(1);
         }
 
@@ -340,7 +341,7 @@ main (int argc, char **argv)
 
         if (argc > 9)
         {
-            printf("%s\n", CP[220]);
+            printf("Time Control Error\n");
             exit(1);
         }
 
@@ -370,7 +371,7 @@ main (int argc, char **argv)
                 XC++;
             else
             {
-                printf("%s\n", CP[220]);
+                printf("Time Control Error\n");
                 exit(1);
             }
 
@@ -385,7 +386,7 @@ main (int argc, char **argv)
              * an error message and quit.
              */
 
-            printf("%s\n", CP[233]);
+            printf("Invalid command-line arguments:\n");
             print_arglist(argc, argv);
             exit(1);
         }
