@@ -6,6 +6,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -16,8 +17,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -25,8 +26,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -34,6 +35,8 @@
 #ifndef _RAWDSP_H_
 #define _RAWDSP_H_
 
+#include "gnushogi.h"
+
 /* The following are common to rawdsp.h and cursesdsp.h */
 
 void Raw_ChangeAlphaWindow(void);
@@ -49,7 +52,9 @@ void Raw_EditBoard(void);
 void Raw_ExitShogi(void);
 void Raw_GiveHint(void);
 void Raw_Initialize(void);
+void Raw_ShowNodeCnt(long NodeCnt);
 void Raw_OutputMove(void);
+void Raw_PollForInput(void);
 void Raw_SearchStartStuff(short side);
 void Raw_SelectLevel(char *sx);
 void Raw_SetContempt(void);
@@ -58,22 +63,23 @@ void Raw_ShowDepth(char ch);
 void Raw_ShowGameType(void);
 void Raw_ShowLine(unsigned short *bstline);
 void Raw_ShowMessage(char *s);
+void Raw_AlwaysShowMessage(const char *format, va_list ap);
+void Raw_Printf(const char *format, va_list ap);
+void Raw_doRequestInputString(const char* fmt, char* buffer);
+int  Raw_GetString(char* sx);
+void Raw_SetupBoard(void);
 void Raw_ShowPatternCount(short side, short n);
 void Raw_ShowPostnValue(short sq);
 void Raw_ShowPostnValues(void);
+void Raw_ShowPrompt(void);
 void Raw_ShowResponseTime(void);
 void Raw_ShowResults(short score, unsigned short *bstline, char ch);
 void Raw_ShowSidetoMove(void);
 void Raw_ShowStage(void);
 void Raw_TerminateSearch(int sig);
+void Raw_UpdateClocks(void);
 void Raw_UpdateDisplay(short f, short t, short redraw, short isspec);
 void Raw_help(void);
 
-
-/* The following are only found in rawdsp.h: */
-
-void PromptForMove(void);
-void SetupBoard(void);
-
 #endif /* _RAWDSP_H_ */
 
