@@ -4,6 +4,7 @@
  * ----------------------------------------------------------------------
  * Copyright (c) 1993, 1994, 1995 Matthias Mutz
  * Copyright (c) 1999 Michael Vanier and the Free Software Foundation
+ * Copyright (c) 2008, 2013, 2014 Yann Dirson and the Free Software Foundation
  *
  * GNU SHOGI is based on GNU CHESS
  *
@@ -14,8 +15,8 @@
  *
  * GNU Shogi is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 1, or (at your option) any
- * later version.
+ * Free Software Foundation; either version 3 of the License,
+ * or (at your option) any later version.
  *
  * GNU Shogi is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -23,8 +24,8 @@
  * for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with GNU Shogi; see the file COPYING.  If not, write to the Free
- * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ * with GNU Shogi; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  * ----------------------------------------------------------------------
  *
  */
@@ -84,10 +85,10 @@ parse(FILE * fd, unsigned short *mv, short side, char *opening)
         return 0;
     }
 
-    c1 = '9' - s[0];
-    r1 = 'i' - s[1];
-    c2 = '9' - s[2];
-    r2 = 'i' - s[3];
+    c1 = COL_NAME(s[0]);
+    r1 = ROW_NAME(s[1]);
+    c2 = COL_NAME(s[2]);
+    r2 = ROW_NAME(s[3]);
     *mv = (locn(r1, c1) << 8) | locn(r2, c2);
 
     if (c == '?')
@@ -175,7 +176,7 @@ ProbeTTable (short side,
 
                 if (!barebones)
                 {
-                    ShowMessage(CP[199]);    /* ttable collision detected */
+                    ShowMessage("ttable collision detected");
                     ShowBD(ptbl->bd);
                     printf("hashkey = 0x%x, hashbd = 0x%x\n",
                            hashkey, hashbd);
